import { __decorate } from "tslib";
import { Component } from 'vue-property-decorator';
import { isBoolean, getControl, getRenderer } from 'handie-vue';
import { SearchStructuralWidget } from 'handie-vue/dist/widgets';
import defaultBehaviors from './behavior';
let PopupSearchWidget = class PopupSearchWidget extends SearchStructuralWidget {
    resolveSearchable() {
        return isBoolean(this.config.searchable)
            ? this.config.searchable
            : this.getBehavior('searchable') !== false;
    }
    resolveResettable() {
        return isBoolean(this.config.resettable)
            ? this.config.resettable
            : this.getBehavior('resettable') === true;
    }
    handleSearch(evt) {
        this.submit();
        if (evt) {
            evt.preventDefault();
        }
    }
    render(h) {
        const formControlSize = this.getBehavior('formControlSize');
        const formChildren = [];
        const filterMap = {};
        this.filters.forEach(filter => {
            if (!filter.hidden) {
                filterMap[filter.name] = filter;
                formChildren.push(h(getControl('FormField'), { props: { label: filter.label } }, [
                    h(getRenderer('FilterRenderer'), {
                        props: { filter, value: this.condition[filter.name] },
                    }),
                ]));
            }
        });
        const searchable = this.resolveSearchable();
        const buttonProps = {
            className: 'PopupSearch-button',
            size: formControlSize,
            nativeType: 'submit',
        };
        if (this.getBehavior('submitButtonAsPrimary') === true) {
            buttonProps.color = 'primary';
        }
        const buttons = [];
        if (searchable) {
            buttons.push(h(getControl('Button'), { props: buttonProps, on: { click: this.handleSearch } }, '查询'));
        }
        if (this.resolveResettable()) {
            buttons.push(h(getControl('Button'), {
                props: { className: 'PopupSearch-button', size: formControlSize },
                on: {
                    click: evt => {
                        this.reset();
                        evt.preventDefault();
                    },
                },
            }, '重置'));
        }
        const buttonGroup = buttons.length > 0 ? h('div', { staticClass: 'PopupSearch-buttonGroup' }, buttons) : null;
        if (buttonGroup) {
            formChildren.push(buttonGroup);
        }
        const searchChildren = [
            h(getControl('Popover'), { props: { trigger: 'click' } }, [
                h(getControl('Button'), [h(getControl('Icon'), { props: { refs: 'el:view' } })]),
                h(getControl('Form'), {
                    props: { value: this.condition, controlSize: formControlSize, layout: 'vertical' },
                    slot: 'content',
                }, formChildren),
            ]),
        ];
        if ((this.config.shortcuts || []).length > 0) {
            const shortcutFilters = [];
            this.config.shortcuts.forEach(filterName => {
                const filter = filterMap[filterName];
                if (filter) {
                    shortcutFilters.push(h(getControl('FormField'), [
                        h(getRenderer('FilterRenderer'), {
                            props: { filter, value: this.condition[filter.name] },
                        }),
                    ]));
                }
            });
            if (shortcutFilters.length > 0) {
                searchChildren.unshift(h(getControl('Form'), { props: { value: this.condition, controlSize: formControlSize, layout: 'inline' } }, shortcutFilters));
            }
        }
        return h('div', searchChildren);
    }
    created() {
        this.setBehaviors('search.popup', defaultBehaviors);
        this.initCondition();
    }
};
PopupSearchWidget = __decorate([
    Component
], PopupSearchWidget);
export default PopupSearchWidget;
